@@ -253,6 +253,7 @@ accept_password_dialog (GtkButton        *button,
 
                 case UM_PASSWORD_DIALOG_MODE_SET_AT_LOGIN:
                         act_user_set_password_mode (um->user, ACT_USER_PASSWORD_MODE_SET_AT_LOGIN);
+                        act_user_set_automatic_login (um->user, FALSE);
                         break;
 
                 case UM_PASSWORD_DIALOG_MODE_NO_PASSWORD:
@@ -261,6 +262,7 @@ accept_password_dialog (GtkButton        *button,
 
                 case UM_PASSWORD_DIALOG_MODE_LOCK_ACCOUNT:
                         act_user_set_locked (um->user, TRUE);
+                        act_user_set_automatic_login (um->user, FALSE);
                         break;
 
                 case UM_PASSWORD_DIALOG_MODE_UNLOCK_ACCOUNT:
@@ -638,7 +640,12 @@ visible_func (GtkTreeModel     *model,
 
                 gtk_tree_model_get (model, iter, 1, &mode, -1);
 
-                if (mode == UM_PASSWORD_DIALOG_MODE_LOCK_ACCOUNT && locked)
+                /* We don't allow the current user to disable their own account,
+                 * as this can lead to them being 'locked out'.
+                 */
+                if (mode == UM_PASSWORD_DIALOG_MODE_LOCK_ACCOUNT &&
+                    (locked || act_user_get_uid (um->user) == getuid ()
+                     || would_demote_only_admin (um->user)))
                         return FALSE;
 
                 if (mode == UM_PASSWORD_DIALOG_MODE_UNLOCK_ACCOUNT && !locked)
